==> netdata-2.5.3.tar.gz: netdata-v2.5.3/src/go/plugin/go.d/collector/init.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package collector

import (
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/activemq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/adaptecraid"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ap"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/apache"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/apcupsd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/beanstalk"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/bind"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/boinc"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/cassandra"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ceph"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/chrony"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/clickhouse"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/cockroachdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/consul"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/coredns"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/couchbase"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/couchdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dmcache"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsdist"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsmasq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsmasq_dhcp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsquery"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/docker"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/docker_engine"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dockerhub"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dovecot"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/elasticsearch"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/envoy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ethtool"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/exim"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/fail2ban"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/filecheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/fluentd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/freeradius"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/gearman"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/geth"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/haproxy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hddtemp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hdfs"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hpssa"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/httpcheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/icecast"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/intelgpu"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ipfs"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/isc_dhcpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_kubelet"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_kubeproxy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_state"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/lighttpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/litespeed"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/logind"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/logstash"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/lvm"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/maxscale"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/megacli"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/memcached"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/mongodb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/monit"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/mysql"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nats"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginx"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxplus"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxunit"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxvts"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nsd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ntpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nvidia_smi"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nvme"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openldap"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openvpn"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openvpn_status_log"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/oracledb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pgbouncer"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/phpdaemon"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/phpfpm"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pihole"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pika"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ping"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/portcheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/postfix"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/postgres"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/powerdns"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/powerdns_recursor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/prometheus"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/proxysql"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pulsar"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/puppet"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rabbitmq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/redis"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rethinkdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/riakkv"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rspamd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/samba"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/scaleio"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/sensors"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/smartctl"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/snmp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/spigotmc"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/squid"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/squidlog"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/storcli"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/supervisord"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/systemdunits"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tengine"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/testrandom"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tomcat"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/traefik"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/typesense"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/unbound"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/upsd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/uwsgi"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/varnish"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vcsa"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vernemq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vsphere"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/w1sensor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/weblog"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/whoisquery"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/wireguard"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/x509check"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/yugabytedb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/zfspool"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/zookeeper"
)

==> netdata-v2.8.1.tar.gz: netdata-v2.8.1/src/go/plugin/go.d/collector/init.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package collector

import (
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/activemq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/adaptecraid"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ap"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/apache"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/apcupsd"
	// _ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/as400" // Moved to ibm.d.plugin (requires CGO)
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/beanstalk"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/bind"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/boinc"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/cassandra"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ceph"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/chrony"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/clickhouse"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/cockroachdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/consul"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/coredns"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/couchbase"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/couchdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dmcache"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsdist"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsmasq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsmasq_dhcp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dnsquery"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/docker"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/docker_engine"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dockerhub"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/dovecot"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/elasticsearch"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/envoy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ethtool"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/exim"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/fail2ban"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/filecheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/fluentd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/freeradius"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/gearman"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/geth"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/haproxy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hddtemp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hdfs"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/hpssa"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/httpcheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/icecast"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/intelgpu"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ipfs"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/isc_dhcpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_kubelet"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_kubeproxy"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/k8s_state"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/lighttpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/litespeed"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/logind"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/logstash"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/lvm"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/maxscale"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/megacli"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/memcached"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/mongodb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/monit"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/mysql"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nats"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginx"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxplus"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxunit"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nginxvts"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nsd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ntpd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nvidia_smi"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/nvme"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openldap"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openvpn"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/openvpn_status_log"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/oracledb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pgbouncer"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/phpdaemon"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/phpfpm"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pihole"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pika"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/ping"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/portcheck"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/postfix"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/postgres"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/powerdns"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/powerdns_recursor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/prometheus"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/proxysql"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/pulsar"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/puppet"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rabbitmq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/redis"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rethinkdb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/riakkv"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/rspamd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/samba"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/scaleio"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/sensors"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/smartctl"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/snmp"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/spigotmc"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/sql"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/squid"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/squidlog"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/storcli"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/supervisord"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/systemdunits"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tengine"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/testrandom"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tomcat"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/tor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/traefik"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/typesense"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/unbound"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/upsd"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/uwsgi"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/varnish"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vcsa"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vernemq"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/vsphere"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/w1sensor"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/weblog"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/whoisquery"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/wireguard"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/x509check"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/yugabytedb"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/zfspool"
	_ "github.com/netdata/netdata/go/plugins/plugin/go.d/collector/zookeeper"
)
